==> openflowplugin-extension-nicira-0.8.2-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/openflowplugin/extension/nicira/action/rev140714/flow/mod/spec/flow/mod/spec/flow/mod/add/match/from/field/_case/FlowModAddMatchFromFieldBuilder.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.flow.mod.spec.flow.mod.spec.flow.mod.add.match.from.field._case;
import com.google.common.base.MoreObjects;
import java.lang.Class;
import java.lang.Integer;
import java.lang.Long;
import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.SuppressWarnings;
import java.util.Collections;
import java.util.HashMap;
import java.util.Map;
import java.util.Objects;
import org.opendaylight.yangtools.concepts.Builder;
import org.opendaylight.yangtools.yang.binding.AbstractAugmentable;
import org.opendaylight.yangtools.yang.binding.Augmentation;
import org.opendaylight.yangtools.yang.binding.AugmentationHolder;
import org.opendaylight.yangtools.yang.binding.CodeHelpers;
import org.opendaylight.yangtools.yang.binding.DataObject;

/**
 * Class that builds {@link FlowModAddMatchFromFieldBuilder} instances.
 *
 * @see FlowModAddMatchFromFieldBuilder
 *
 */
public class FlowModAddMatchFromFieldBuilder implements Builder<FlowModAddMatchFromField> {

    private Long _dstField;
    private Integer _dstOfs;
    private Integer _flowModNumBits;
    private Long _srcField;
    private Integer _srcOfs;


    Map<Class<? extends Augmentation<FlowModAddMatchFromField>>, Augmentation<FlowModAddMatchFromField>> augmentation = Collections.emptyMap();

    public FlowModAddMatchFromFieldBuilder() {
    }

    public FlowModAddMatchFromFieldBuilder(FlowModAddMatchFromField base) {
        if (base instanceof AugmentationHolder) {
            @SuppressWarnings("unchecked")
            Map<Class<? extends Augmentation<FlowModAddMatchFromField>>, Augmentation<FlowModAddMatchFromField>> aug =((AugmentationHolder<FlowModAddMatchFromField>) base).augmentations();
            if (!aug.isEmpty()) {
                this.augmentation = new HashMap<>(aug);
            }
        }
        this._dstField = base.getDstField();
        this._dstOfs = base.getDstOfs();
        this._flowModNumBits = base.getFlowModNumBits();
        this._srcField = base.getSrcField();
        this._srcOfs = base.getSrcOfs();
    }


    public Long getDstField() {
        return _dstField;
    }
    
    public Integer getDstOfs() {
        return _dstOfs;
    }
    
    public Integer getFlowModNumBits() {
        return _flowModNumBits;
    }
    
    public Long getSrcField() {
        return _srcField;
    }
    
    public Integer getSrcOfs() {
        return _srcOfs;
    }

    @SuppressWarnings({ "unchecked", "checkstyle:methodTypeParameterName"})
    public <E$$ extends Augmentation<FlowModAddMatchFromField>> E$$ augmentation(Class<E$$> augmentationType) {
        return (E$$) augmentation.get(CodeHelpers.nonNullValue(augmentationType, "augmentationType"));
    }

    private static void checkDstFieldRange(final long value) {
        if (value >= 0L && value <= 4294967295L) {
            return;
        }
        CodeHelpers.throwInvalidRange("[[0..4294967295]]", value);
    }
    
    public FlowModAddMatchFromFieldBuilder setDstField(final Long value) {
    if (value != null) {
        checkDstFieldRange(value);
        
    }
        this._dstField = value;
        return this;
    }
    private static void checkDstOfsRange(final int value) {
        if (value >= 0 && value <= 65535) {
            return;
        }
        CodeHelpers.throwInvalidRange("[[0..65535]]", value);
    }
    
    public FlowModAddMatchFromFieldBuilder setDstOfs(final Integer value) {
    if (value != null) {
        checkDstOfsRange(value);
        
    }
        this._dstOfs = value;
        return this;
    }
    private static void checkFlowModNumBitsRange(final int value) {
        if (value >= 0 && value <= 65535) {
            return;
        }
        CodeHelpers.throwInvalidRange("[[0..65535]]", value);
    }
    
    public FlowModAddMatchFromFieldBuilder setFlowModNumBits(final Integer value) {
    if (value != null) {
        checkFlowModNumBitsRange(value);
        
    }
        this._flowModNumBits = value;
        return this;
    }
    private static void checkSrcFieldRange(final long value) {
        if (value >= 0L && value <= 4294967295L) {
            return;
        }
        CodeHelpers.throwInvalidRange("[[0..4294967295]]", value);
    }
    
    public FlowModAddMatchFromFieldBuilder setSrcField(final Long value) {
    if (value != null) {
        checkSrcFieldRange(value);
        
    }
        this._srcField = value;
        return this;
    }
    private static void checkSrcOfsRange(final int value) {
        if (value >= 0 && value <= 65535) {
            return;
        }
        CodeHelpers.throwInvalidRange("[[0..65535]]", value);
    }
    
    public FlowModAddMatchFromFieldBuilder setSrcOfs(final Integer value) {
    if (value != null) {
        checkSrcOfsRange(value);
        
    }
        this._srcOfs = value;
        return this;
    }
    
    public FlowModAddMatchFromFieldBuilder addAugmentation(Class<? extends Augmentation<FlowModAddMatchFromField>> augmentationType, Augmentation<FlowModAddMatchFromField> augmentationValue) {
        if (augmentationValue == null) {
            return removeAugmentation(augmentationType);
        }
    
        if (!(this.augmentation instanceof HashMap)) {
            this.augmentation = new HashMap<>();
        }
    
        this.augmentation.put(augmentationType, augmentationValue);
        return this;
    }
    
    public FlowModAddMatchFromFieldBuilder removeAugmentation(Class<? extends Augmentation<FlowModAddMatchFromField>> augmentationType) {
        if (this.augmentation instanceof HashMap) {
            this.augmentation.remove(augmentationType);
        }
        return this;
    }

    @Override
    public FlowModAddMatchFromField build() {
        return new FlowModAddMatchFromFieldImpl(this);
    }

    private static final class FlowModAddMatchFromFieldImpl
        extends AbstractAugmentable<FlowModAddMatchFromField>
        implements FlowModAddMatchFromField {
    
        private final Long _dstField;
        private final Integer _dstOfs;
        private final Integer _flowModNumBits;
        private final Long _srcField;
        private final Integer _srcOfs;
    
        FlowModAddMatchFromFieldImpl(FlowModAddMatchFromFieldBuilder base) {
            super(base.augmentation);
            this._dstField = base.getDstField();
            this._dstOfs = base.getDstOfs();
            this._flowModNumBits = base.getFlowModNumBits();
            this._srcField = base.getSrcField();
            this._srcOfs = base.getSrcOfs();
        }
    
        @Override
        public Class<FlowModAddMatchFromField> getImplementedInterface() {
            return FlowModAddMatchFromField.class;
        }
    
        @Override
        public Long getDstField() {
            return _dstField;
        }
        
        @Override
        public Integer getDstOfs() {
            return _dstOfs;
        }
        
        @Override
        public Integer getFlowModNumBits() {
            return _flowModNumBits;
        }
        
        @Override
        public Long getSrcField() {
            return _srcField;
        }
        
        @Override
        public Integer getSrcOfs() {
            return _srcOfs;
        }
    
        private int hash = 0;
        private volatile boolean hashValid = false;
        
        @Override
        public int hashCode() {
            if (hashValid) {
                return hash;
            }
        
            final int prime = 31;
            int result = 1;
            result = prime * result + Objects.hashCode(_dstField);
            result = prime * result + Objects.hashCode(_dstOfs);
            result = prime * result + Objects.hashCode(_flowModNumBits);
            result = prime * result + Objects.hashCode(_srcField);
            result = prime * result + Objects.hashCode(_srcOfs);
            result = prime * result + Objects.hashCode(augmentations());
        
            hash = result;
            hashValid = true;
            return result;
        }
    
        @Override
        public boolean equals(Object obj) {
            if (this == obj) {
                return true;
            }
            if (!(obj instanceof DataObject)) {
                return false;
            }
            if (!FlowModAddMatchFromField.class.equals(((DataObject)obj).getImplementedInterface())) {
                return false;
            }
            FlowModAddMatchFromField other = (FlowModAddMatchFromField)obj;
            if (!Objects.equals(_dstField, other.getDstField())) {
                return false;
            }
            if (!Objects.equals(_dstOfs, other.getDstOfs())) {
                return false;
            }
            if (!Objects.equals(_flowModNumBits, other.getFlowModNumBits())) {
                return false;
            }
            if (!Objects.equals(_srcField, other.getSrcField())) {
                return false;
            }
            if (!Objects.equals(_srcOfs, other.getSrcOfs())) {
                return false;
            }
            if (getClass() == obj.getClass()) {
                // Simple case: we are comparing against self
                FlowModAddMatchFromFieldImpl otherImpl = (FlowModAddMatchFromFieldImpl) obj;
                if (!Objects.equals(augmentations(), otherImpl.augmentations())) {
                    return false;
                }
            } else {
                // Hard case: compare our augments with presence there...
                for (Map.Entry<Class<? extends Augmentation<FlowModAddMatchFromField>>, Augmentation<FlowModAddMatchFromField>> e : augmentations().entrySet()) {
                    if (!e.getValue().equals(other.augmentation(e.getKey()))) {
                        return false;
                    }
                }
                // .. and give the other one the chance to do the same
                if (!obj.equals(this)) {
                    return false;
                }
            }
            return true;
        }
    
        @Override
        public String toString() {
            final MoreObjects.ToStringHelper helper = MoreObjects.toStringHelper("FlowModAddMatchFromField");
            CodeHelpers.appendValue(helper, "_dstField", _dstField);
            CodeHelpers.appendValue(helper, "_dstOfs", _dstOfs);
            CodeHelpers.appendValue(helper, "_flowModNumBits", _flowModNumBits);
            CodeHelpers.appendValue(helper, "_srcField", _srcField);
            CodeHelpers.appendValue(helper, "_srcOfs", _srcOfs);
            CodeHelpers.appendValue(helper, "augmentation", augmentations().values());
            return helper.toString();
        }
    }
}

==> openflowplugin-extension-nicira-0.8.3-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/openflowplugin/extension/nicira/action/rev140714/flow/mod/spec/flow/mod/spec/flow/mod/add/match/from/field/_case/FlowModAddMatchFromFieldBuilder.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.flow.mod.spec.flow.mod.spec.flow.mod.add.match.from.field._case;
import com.google.common.base.MoreObjects;
import java.lang.Class;
import java.lang.Integer;
import java.lang.Long;
import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.SuppressWarnings;
import java.util.Collections;
import java.util.HashMap;
import java.util.Map;
import java.util.Objects;
import org.opendaylight.yangtools.concepts.Builder;
import org.opendaylight.yangtools.yang.binding.AbstractAugmentable;
import org.opendaylight.yangtools.yang.binding.Augmentation;
import org.opendaylight.yangtools.yang.binding.AugmentationHolder;
import org.opendaylight.yangtools.yang.binding.CodeHelpers;
import org.opendaylight.yangtools.yang.binding.DataObject;

/**
 * Class that builds {@link FlowModAddMatchFromFieldBuilder} instances. Overall design of the class is that of a
 * <a href="https://en.wikipedia.org/wiki/Fluent_interface">fluent interface</a>, where method chaining is used.
 *
 * <p>
 * In general, this class is supposed to be used like this template:
 * <pre>
 *   <code>
 *     FlowModAddMatchFromFieldBuilder createTarget(int fooXyzzy, int barBaz) {
 *         return new FlowModAddMatchFromFieldBuilderBuilder()
 *             .setFoo(new FooBuilder().setXyzzy(fooXyzzy).build())
 *             .setBar(new BarBuilder().setBaz(barBaz).build())
 *             .build();
 *     }
 *   </code>
 * </pre>
 *
 * <p>
 * This pattern is supported by the immutable nature of FlowModAddMatchFromFieldBuilder, as instances can be freely passed around without
 * worrying about synchronization issues.
 *
 * <p>
 * As a side note: method chaining results in:
 * <ul>
 *   <li>very efficient Java bytecode, as the method invocation result, in this case the Builder reference, is
 *       on the stack, so further method invocations just need to fill method arguments for the next method
 *       invocation, which is terminated by {@link #build()}, which is then returned from the method</li>
 *   <li>better understanding by humans, as the scope of mutable state (the builder) is kept to a minimum and is
 *       very localized</li>
 *   <li>better optimization oportunities, as the object scope is minimized in terms of invocation (rather than
 *       method) stack, making <a href="https://en.wikipedia.org/wiki/Escape_analysis">escape analysis</a> a lot
 *       easier. Given enough compiler (JIT/AOT) prowess, the cost of th builder object can be completely
 *       eliminated</li>
 * </ul>
 *
 * @see FlowModAddMatchFromFieldBuilder
 * @see Builder
 *
 */
public class FlowModAddMatchFromFieldBuilder implements Builder<FlowModAddMatchFromField> {

    private Long _dstField;
    private Integer _dstOfs;
    private Integer _flowModNumBits;
    private Long _srcField;
    private Integer _srcOfs;


    Map<Class<? extends Augmentation<FlowModAddMatchFromField>>, Augmentation<FlowModAddMatchFromField>> augmentation = Collections.emptyMap();

    public FlowModAddMatchFromFieldBuilder() {
    }

    public FlowModAddMatchFromFieldBuilder(FlowModAddMatchFromField base) {
        if (base instanceof AugmentationHolder) {
            @SuppressWarnings("unchecked")
            Map<Class<? extends Augmentation<FlowModAddMatchFromField>>, Augmentation<FlowModAddMatchFromField>> aug =((AugmentationHolder<FlowModAddMatchFromField>) base).augmentations();
            if (!aug.isEmpty()) {
                this.augmentation = new HashMap<>(aug);
            }
        }
        this._dstField = base.getDstField();
        this._dstOfs = base.getDstOfs();
        this._flowModNumBits = base.getFlowModNumBits();
        this._srcField = base.getSrcField();
        this._srcOfs = base.getSrcOfs();
    }


    public Long getDstField() {
        return _dstField;
    }
    
    public Integer getDstOfs() {
        return _dstOfs;
    }
    
    public Integer getFlowModNumBits() {
        return _flowModNumBits;
    }
    
    public Long getSrcField() {
        return _srcField;
    }
    
    public Integer getSrcOfs() {
        return _srcOfs;
    }

    @SuppressWarnings({ "unchecked", "checkstyle:methodTypeParameterName"})
    public <E$$ extends Augmentation<FlowModAddMatchFromField>> E$$ augmentation(Class<E$$> augmentationType) {
        return (E$$) augmentation.get(CodeHelpers.nonNullValue(augmentationType, "augmentationType"));
    }

    private static void checkDstFieldRange(final long value) {
        if (value >= 0L && value <= 4294967295L) {
            return;
        }
        CodeHelpers.throwInvalidRange("[[0..4294967295]]", value);
    }
    
    public FlowModAddMatchFromFieldBuilder setDstField(final Long value) {
    if (value != null) {
        checkDstFieldRange(value);
        
    }
        this._dstField = value;
        return this;
    }
    private static void checkDstOfsRange(final int value) {
        if (value >= 0 && value <= 65535) {
            return;
        }
        CodeHelpers.throwInvalidRange("[[0..65535]]", value);
    }
    
    public FlowModAddMatchFromFieldBuilder setDstOfs(final Integer value) {
    if (value != null) {
        checkDstOfsRange(value);
        
    }
        this._dstOfs = value;
        return this;
    }
    private static void checkFlowModNumBitsRange(final int value) {
        if (value >= 0 && value <= 65535) {
            return;
        }
        CodeHelpers.throwInvalidRange("[[0..65535]]", value);
    }
    
    public FlowModAddMatchFromFieldBuilder setFlowModNumBits(final Integer value) {
    if (value != null) {
        checkFlowModNumBitsRange(value);
        
    }
        this._flowModNumBits = value;
        return this;
    }
    private static void checkSrcFieldRange(final long value) {
        if (value >= 0L && value <= 4294967295L) {
            return;
        }
        CodeHelpers.throwInvalidRange("[[0..4294967295]]", value);
    }
    
    public FlowModAddMatchFromFieldBuilder setSrcField(final Long value) {
    if (value != null) {
        checkSrcFieldRange(value);
        
    }
        this._srcField = value;
        return this;
    }
    private static void checkSrcOfsRange(final int value) {
        if (value >= 0 && value <= 65535) {
            return;
        }
        CodeHelpers.throwInvalidRange("[[0..65535]]", value);
    }
    
    public FlowModAddMatchFromFieldBuilder setSrcOfs(final Integer value) {
    if (value != null) {
        checkSrcOfsRange(value);
        
    }
        this._srcOfs = value;
        return this;
    }
    
    public FlowModAddMatchFromFieldBuilder addAugmentation(Class<? extends Augmentation<FlowModAddMatchFromField>> augmentationType, Augmentation<FlowModAddMatchFromField> augmentationValue) {
        if (augmentationValue == null) {
            return removeAugmentation(augmentationType);
        }
    
        if (!(this.augmentation instanceof HashMap)) {
            this.augmentation = new HashMap<>();
        }
    
        this.augmentation.put(augmentationType, augmentationValue);
        return this;
    }
    
    public FlowModAddMatchFromFieldBuilder removeAugmentation(Class<? extends Augmentation<FlowModAddMatchFromField>> augmentationType) {
        if (this.augmentation instanceof HashMap) {
            this.augmentation.remove(augmentationType);
        }
        return this;
    }

    @Override
    public FlowModAddMatchFromField build() {
        return new FlowModAddMatchFromFieldImpl(this);
    }

    private static final class FlowModAddMatchFromFieldImpl
        extends AbstractAugmentable<FlowModAddMatchFromField>
        implements FlowModAddMatchFromField {
    
        private final Long _dstField;
        private final Integer _dstOfs;
        private final Integer _flowModNumBits;
        private final Long _srcField;
        private final Integer _srcOfs;
    
        FlowModAddMatchFromFieldImpl(FlowModAddMatchFromFieldBuilder base) {
            super(base.augmentation);
            this._dstField = base.getDstField();
            this._dstOfs = base.getDstOfs();
            this._flowModNumBits = base.getFlowModNumBits();
            this._srcField = base.getSrcField();
            this._srcOfs = base.getSrcOfs();
        }
    
        @Override
        public Class<FlowModAddMatchFromField> getImplementedInterface() {
            return FlowModAddMatchFromField.class;
        }
    
        @Override
        public Long getDstField() {
            return _dstField;
        }
        
        @Override
        public Integer getDstOfs() {
            return _dstOfs;
        }
        
        @Override
        public Integer getFlowModNumBits() {
            return _flowModNumBits;
        }
        
        @Override
        public Long getSrcField() {
            return _srcField;
        }
        
        @Override
        public Integer getSrcOfs() {
            return _srcOfs;
        }
    
        private int hash = 0;
        private volatile boolean hashValid = false;
        
        @Override
        public int hashCode() {
            if (hashValid) {
                return hash;
            }
        
            final int prime = 31;
            int result = 1;
            result = prime * result + Objects.hashCode(_dstField);
            result = prime * result + Objects.hashCode(_dstOfs);
            result = prime * result + Objects.hashCode(_flowModNumBits);
            result = prime * result + Objects.hashCode(_srcField);
            result = prime * result + Objects.hashCode(_srcOfs);
            result = prime * result + Objects.hashCode(augmentations());
        
            hash = result;
            hashValid = true;
            return result;
        }
    
        @Override
        public boolean equals(Object obj) {
            if (this == obj) {
                return true;
            }
            if (!(obj instanceof DataObject)) {
                return false;
            }
            if (!FlowModAddMatchFromField.class.equals(((DataObject)obj).getImplementedInterface())) {
                return false;
            }
            FlowModAddMatchFromField other = (FlowModAddMatchFromField)obj;
            if (!Objects.equals(_dstField, other.getDstField())) {
                return false;
            }
            if (!Objects.equals(_dstOfs, other.getDstOfs())) {
                return false;
            }
            if (!Objects.equals(_flowModNumBits, other.getFlowModNumBits())) {
                return false;
            }
            if (!Objects.equals(_srcField, other.getSrcField())) {
                return false;
            }
            if (!Objects.equals(_srcOfs, other.getSrcOfs())) {
                return false;
            }
            if (getClass() == obj.getClass()) {
                // Simple case: we are comparing against self
                FlowModAddMatchFromFieldImpl otherImpl = (FlowModAddMatchFromFieldImpl) obj;
                if (!Objects.equals(augmentations(), otherImpl.augmentations())) {
                    return false;
                }
            } else {
                // Hard case: compare our augments with presence there...
                for (Map.Entry<Class<? extends Augmentation<FlowModAddMatchFromField>>, Augmentation<FlowModAddMatchFromField>> e : augmentations().entrySet()) {
                    if (!e.getValue().equals(other.augmentation(e.getKey()))) {
                        return false;
                    }
                }
                // .. and give the other one the chance to do the same
                if (!obj.equals(this)) {
                    return false;
                }
            }
            return true;
        }
    
        @Override
        public String toString() {
            final MoreObjects.ToStringHelper helper = MoreObjects.toStringHelper("FlowModAddMatchFromField");
            CodeHelpers.appendValue(helper, "_dstField", _dstField);
            CodeHelpers.appendValue(helper, "_dstOfs", _dstOfs);
            CodeHelpers.appendValue(helper, "_flowModNumBits", _flowModNumBits);
            CodeHelpers.appendValue(helper, "_srcField", _srcField);
            CodeHelpers.appendValue(helper, "_srcOfs", _srcOfs);
            CodeHelpers.appendValue(helper, "augmentation", augmentations().values());
            return helper.toString();
        }
    }
}
